:orphan:

Miscellanea *To Do* list
------------------------

* improve documentation
* improve typing
* benchmarks
* :class:`EBaseUnits` shall become a :class:`IntFlag` to allow the
  *decoders* to declare base-units as follows::

    baseunits = bpack.EBaseUnits.BITS | bpack.EBaseUnits.BYTES

* nested records and repeat (test)
* decoder attributes (Decoder.descriptor)
